==> dev-plugin-android-6.1.8-beta1-sources.jar: com/zoyi/channel/plugin/android/activity/settings2/SettingsActivity.java <==
package com.zoyi.channel.plugin.android.activity.settings2;

import android.support.annotation.Nullable;
import android.support.v7.widget.SwitchCompat;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.zoyi.channel.plugin.android.BuildConfig;
import com.zoyi.channel.plugin.android.CHLocale;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.base.BaseActivity2;
import com.zoyi.channel.plugin.android.activity.common.error.ErrorRefreshView;
import com.zoyi.channel.plugin.android.activity.common.navigation.NavigationView;
import com.zoyi.channel.plugin.android.activity.language.LanguageSettingsActivity;
import com.zoyi.channel.plugin.android.activity.profile.EditProfileActivity;
import com.zoyi.channel.plugin.android.activity.settings2.contract.SettingsContract;
import com.zoyi.channel.plugin.android.activity.settings2.enumerate.OptionType;
import com.zoyi.channel.plugin.android.activity.settings2.view.SettingsHeaderView;
import com.zoyi.channel.plugin.android.activity.settings2.view.SettingsOptionInteractionListener;
import com.zoyi.channel.plugin.android.activity.settings2.view.SettingsOptionView;
import com.zoyi.channel.plugin.android.enumerate.ActionType;
import com.zoyi.channel.plugin.android.enumerate.FetchState;
import com.zoyi.channel.plugin.android.global.Action;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.global.PrefSupervisor;
import com.zoyi.channel.plugin.android.model.entity.Guest;
import com.zoyi.channel.plugin.android.model.rest.ProfileBotSchema;
import com.zoyi.channel.plugin.android.store2.SettingsStore;
import com.zoyi.channel.plugin.android.util.Initializer;
import com.zoyi.channel.plugin.android.util.IntentUtils;
import com.zoyi.channel.plugin.android.util.ResUtils;

import java.util.List;

public class SettingsActivity
    extends BaseActivity2
    implements
    SettingsContract.View,
    CompoundButton.OnCheckedChangeListener,
    SettingsOptionInteractionListener {

  private SettingsContract.Presenter presenter;

  private NavigationView navigation;
  private SettingsHeaderView header;

  private SettingsOptionView optionLanguage;

  private SwitchCompat switchTranslation;
  private SwitchCompat switchShowClosedChat;
  private SwitchCompat switchSoundVibrate;

  private View profileLayout;
  private TextView textSettingsProfile;
  private LinearLayout profileContents;
  private View profileLoader;
  private ErrorRefreshView profileErrorView;

  private TextView textVersion;

  @Initializer
  @Override
  protected boolean onCreate() {
    init(R.layout.ch_plugin_activity_settings);

    navigation = findViewById(R.id.navigationSettings);

    header = findViewById(R.id.headerSettings);

    optionLanguage = findViewById(R.id.optionLanguage);
    optionLanguage.setData(OptionType.LANGUAGE, ResUtils.getString(SettingsStore.get().locale.get().toString()));
    optionLanguage.setSettingsOptionInteractionListener(this);

    switchTranslation = findViewById(R.id.switchTranslation);
    switchTranslation.setChecked(SettingsStore.get().showTranslation.get());
    switchTranslation.setOnCheckedChangeListener(this);

    switchShowClosedChat = findViewById(R.id.switchShowClosedChats);
    switchShowClosedChat.setChecked(SettingsStore.get().showClosedChat.get());
    switchShowClosedChat.setOnCheckedChangeListener(this);

    switchSoundVibrate = findViewById(R.id.switchSoundVibrate);
    switchSoundVibrate.setChecked(SettingsStore.get().raiseSoundVibrate.get());
    switchSoundVibrate.setOnCheckedChangeListener(this);

    profileLayout = findViewById(R.id.layoutSettingsProfile);
    textSettingsProfile = findViewById(R.id.textSettingsProfile);
    profileContents = findViewById(R.id.layoutSettingsProfileContent);
    profileLoader = findViewById(R.id.loaderSettingsProfile);
    profileErrorView = findViewById(R.id.errorSettingsProfile);
    profileErrorView.setListener(v -> presenter.fetchProfileBotSchema());

    textVersion = findViewById(R.id.textSettingsVersion);
    textVersion.setText(String.format("v%s", BuildConfig.VERSION_NAME));

    presenter = new SettingsPresenter(this);

    bindPresenter(presenter);

    return true;
  }

  @Override
  protected void onDestroy() {
    super.onDestroy();

    Action.invoke(ActionType.SETTINGS_CLOSED);
  }

  @Override
  public void onLocaleChange(CHLocale locale) {
    optionLanguage.setData(OptionType.LANGUAGE, ResUtils.getString(locale.toString()));
  }

  @Override
  public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
    if (buttonView == null) {
      return;
    }

    int id = buttonView.getId();

    if (id == R.id.switchTranslation) {
      SettingsStore.get().showTranslation.set(isChecked);
      PrefSupervisor.setTranslateOption(this, isChecked);
    } else if (id == R.id.switchShowClosedChats) {
      SettingsStore.get().showClosedChat.set(isChecked);
      PrefSupervisor.setShowClosedChat(this, isChecked);
    } else if (id == R.id.switchSoundVibrate) {
      SettingsStore.get().raiseSoundVibrate.set(isChecked);
      PrefSupervisor.setPushAlarm(this, isChecked);
    }
  }

  @Override
  public void onOptionClick(OptionType optionType, @Nullable String key, @Nullable String value) {
    switch (optionType) {
      case LANGUAGE:
        IntentUtils.setNextActivity(this, LanguageSettingsActivity.class).startActivity();
        break;

      case PROFILE:
        if (key != null) {
          IntentUtils.setNextActivity(this, EditProfileActivity.class)
              .putExtra(Const.EXTRA_PROFILE_KEY, key)
              .putExtra(Const.EXTRA_PROFILE_VALUE, value)
              .startActivity();
        }
        break;
    }
  }

  @Override
  public void onProfileBotSchemasFetchStateChange(FetchState state) {
    profileLayout.setVisibility(View.GONE);
    profileLoader.setVisibility(View.GONE);
    profileErrorView.setVisibility(View.GONE);

    switch (state) {
      case COMPLETE:
        profileLayout.setVisibility(View.VISIBLE);
        break;

      case LOADING:
        profileLoader.setVisibility(View.VISIBLE);
        break;

      case FAILED:
        profileErrorView.setVisibility(View.VISIBLE);
        break;
    }
  }

  @Override
  public void onProfileBotSchemasChange(List<ProfileBotSchema> profileBotSchemas, Guest guest) {
    if (profileBotSchemas.size() > 0) {
      textSettingsProfile.setVisibility(View.VISIBLE);
      profileContents.setVisibility(View.VISIBLE);

      for (int i = 0; i < profileBotSchemas.size(); i++) {
        if (profileContents.getChildCount() <= i) {
          SettingsOptionView newOptionView = new SettingsOptionView(this);
          newOptionView.setSettingsOptionInteractionListener(this);

          profileContents.addView(newOptionView);
        }

        ProfileBotSchema schema = profileBotSchemas.get(i);
        SettingsOptionView optionView = (SettingsOptionView) profileContents.getChildAt(i);

        if (schema != null && schema.getNameI18n() != null && schema.getNameI18n().get() != null) {
          optionView.setData(schema, guest);
          optionView.setVisibility(View.VISIBLE);
        } else {
          optionView.setVisibility(View.GONE);
        }
      }

      for (int i = profileBotSchemas.size(); i < profileContents.getChildCount(); i++) {
        profileContents.getChildAt(i).setVisibility(View.GONE);
      }
    } else {
      textSettingsProfile.setVisibility(View.GONE);
      profileContents.setVisibility(View.GONE);
    }
  }
}

==> dev-plugin-android-6.1.9-beta1-sources.jar: com/zoyi/channel/plugin/android/activity/settings2/SettingsActivity.java <==
package com.zoyi.channel.plugin.android.activity.settings2;

import android.support.annotation.Nullable;
import android.support.v7.widget.SwitchCompat;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.zoyi.channel.plugin.android.BuildConfig;
import com.zoyi.channel.plugin.android.CHLocale;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.base.BaseActivity2;
import com.zoyi.channel.plugin.android.activity.common.error.ErrorRefreshView;
import com.zoyi.channel.plugin.android.activity.common.navigation.NavigationView;
import com.zoyi.channel.plugin.android.activity.language.LanguageSettingsActivity;
import com.zoyi.channel.plugin.android.activity.profile.EditProfileActivity;
import com.zoyi.channel.plugin.android.activity.settings2.contract.SettingsContract;
import com.zoyi.channel.plugin.android.activity.settings2.enumerate.OptionType;
import com.zoyi.channel.plugin.android.activity.settings2.view.SettingsHeaderView;
import com.zoyi.channel.plugin.android.activity.settings2.view.SettingsOptionInteractionListener;
import com.zoyi.channel.plugin.android.activity.settings2.view.SettingsOptionView;
import com.zoyi.channel.plugin.android.enumerate.ActionType;
import com.zoyi.channel.plugin.android.enumerate.FetchState;
import com.zoyi.channel.plugin.android.global.Action;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.global.PrefSupervisor;
import com.zoyi.channel.plugin.android.model.entity.Guest;
import com.zoyi.channel.plugin.android.model.rest.ProfileBotSchema;
import com.zoyi.channel.plugin.android.store2.SettingsStore;
import com.zoyi.channel.plugin.android.util.Initializer;
import com.zoyi.channel.plugin.android.util.IntentUtils;
import com.zoyi.channel.plugin.android.util.ResUtils;

import java.util.List;

public class SettingsActivity
    extends BaseActivity2
    implements
    SettingsContract.View,
    CompoundButton.OnCheckedChangeListener,
    SettingsOptionInteractionListener {

  private SettingsContract.Presenter presenter;

  private NavigationView navigation;
  private SettingsHeaderView header;

  private SettingsOptionView optionLanguage;

  private SwitchCompat switchTranslation;
  private SwitchCompat switchShowClosedChat;
  private SwitchCompat switchSoundVibrate;

  private View profileLayout;
  private TextView textSettingsProfile;
  private LinearLayout profileContents;
  private View profileLoader;
  private ErrorRefreshView profileErrorView;

  private TextView textVersion;

  @Initializer
  @Override
  protected boolean onCreate() {
    init(R.layout.ch_plugin_activity_settings);

    navigation = findViewById(R.id.navigationSettings);

    header = findViewById(R.id.headerSettings);

    optionLanguage = findViewById(R.id.optionLanguage);
    optionLanguage.setData(OptionType.LANGUAGE, ResUtils.getString(SettingsStore.get().locale.get().toString()));
    optionLanguage.setSettingsOptionInteractionListener(this);

    switchTranslation = findViewById(R.id.switchTranslation);
    switchTranslation.setChecked(SettingsStore.get().showTranslation.get());
    switchTranslation.setOnCheckedChangeListener(this);

    switchShowClosedChat = findViewById(R.id.switchShowClosedChats);
    switchShowClosedChat.setChecked(SettingsStore.get().showClosedChat.get());
    switchShowClosedChat.setOnCheckedChangeListener(this);

    switchSoundVibrate = findViewById(R.id.switchSoundVibrate);
    switchSoundVibrate.setChecked(SettingsStore.get().raiseSoundVibrate.get());
    switchSoundVibrate.setOnCheckedChangeListener(this);

    profileLayout = findViewById(R.id.layoutSettingsProfile);
    textSettingsProfile = findViewById(R.id.textSettingsProfile);
    profileContents = findViewById(R.id.layoutSettingsProfileContent);
    profileLoader = findViewById(R.id.loaderSettingsProfile);
    profileErrorView = findViewById(R.id.errorSettingsProfile);
    profileErrorView.setListener(v -> presenter.fetchProfileBotSchema());

    textVersion = findViewById(R.id.textSettingsVersion);
    textVersion.setText(String.format("v%s", BuildConfig.VERSION_NAME));

    presenter = new SettingsPresenter(this);

    bindPresenter(presenter);

    return true;
  }

  @Override
  protected void onPause() {
    super.onPause();

    if (isFinishing()) {
      Action.invoke(ActionType.SETTINGS_CLOSED);
    }
  }

  @Override
  public void onLocaleChange(CHLocale locale) {
    optionLanguage.setData(OptionType.LANGUAGE, ResUtils.getString(locale.toString()));
  }

  @Override
  public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
    if (buttonView == null) {
      return;
    }

    int id = buttonView.getId();

    if (id == R.id.switchTranslation) {
      SettingsStore.get().showTranslation.set(isChecked);
      PrefSupervisor.setTranslateOption(this, isChecked);
    } else if (id == R.id.switchShowClosedChats) {
      SettingsStore.get().showClosedChat.set(isChecked);
      PrefSupervisor.setShowClosedChat(this, isChecked);
    } else if (id == R.id.switchSoundVibrate) {
      SettingsStore.get().raiseSoundVibrate.set(isChecked);
      PrefSupervisor.setPushAlarm(this, isChecked);
    }
  }

  @Override
  public void onOptionClick(OptionType optionType, @Nullable String key, @Nullable String value) {
    switch (optionType) {
      case LANGUAGE:
        IntentUtils.setNextActivity(this, LanguageSettingsActivity.class).startActivity();
        break;

      case PROFILE:
        if (key != null) {
          IntentUtils.setNextActivity(this, EditProfileActivity.class)
              .putExtra(Const.EXTRA_PROFILE_KEY, key)
              .putExtra(Const.EXTRA_PROFILE_VALUE, value)
              .startActivity();
        }
        break;
    }
  }

  @Override
  public void onProfileBotSchemasFetchStateChange(FetchState state) {
    profileLayout.setVisibility(View.GONE);
    profileLoader.setVisibility(View.GONE);
    profileErrorView.setVisibility(View.GONE);

    switch (state) {
      case COMPLETE:
        profileLayout.setVisibility(View.VISIBLE);
        break;

      case LOADING:
        profileLoader.setVisibility(View.VISIBLE);
        break;

      case FAILED:
        profileErrorView.setVisibility(View.VISIBLE);
        break;
    }
  }

  @Override
  public void onProfileBotSchemasChange(List<ProfileBotSchema> profileBotSchemas, Guest guest) {
    if (profileBotSchemas.size() > 0) {
      textSettingsProfile.setVisibility(View.VISIBLE);
      profileContents.setVisibility(View.VISIBLE);

      for (int i = 0; i < profileBotSchemas.size(); i++) {
        if (profileContents.getChildCount() <= i) {
          SettingsOptionView newOptionView = new SettingsOptionView(this);
          newOptionView.setSettingsOptionInteractionListener(this);

          profileContents.addView(newOptionView);
        }

        ProfileBotSchema schema = profileBotSchemas.get(i);
        SettingsOptionView optionView = (SettingsOptionView) profileContents.getChildAt(i);

        if (schema != null && schema.getNameI18n() != null && schema.getNameI18n().get() != null) {
          optionView.setData(schema, guest);
          optionView.setVisibility(View.VISIBLE);
        } else {
          optionView.setVisibility(View.GONE);
        }
      }

      for (int i = profileBotSchemas.size(); i < profileContents.getChildCount(); i++) {
        profileContents.getChildAt(i).setVisibility(View.GONE);
      }
    } else {
      textSettingsProfile.setVisibility(View.GONE);
      profileContents.setVisibility(View.GONE);
    }
  }
}
